@@ -137,7 +137,7 @@ def ReadSpec(fname, scan, outputdate=False):
 
 class SpecFile:
     """
-    Simple class to read SPEC file. The main purposes are :
+    Simple class to read SPEC and hdf5 file. The main purposes are :
     (i) read the header and initiate the relevant properties
     (ii) build a dictionary of the scan number and their binary position in the file
     The latter allows for faster subsequent scan reading
@@ -254,8 +254,7 @@ class SpecFile:
 
         if filetype == 'spec':
             try:
-                with open(spec_file,
-                        'rU') as f:  # the U mode indicates universal line break, essential for accurate counting
+                with open(spec_file, 'rU') as f:  # the U mode indicates universal line break, essential for accurate counting
                     # first read the file header (mostly comments and motors definition)
                     # up to the first scan (identified by a line starting with "#S"
                     reading_header = True
@@ -298,7 +297,7 @@ class SpecFile:
             self.scan_dict = get_scandict(selp)
             self.cmd_list = get_cmd_list(selp)
 
-
+# helper function of listprops generated by getwirescan_from_hdf5file
 def get_cmd_list(listprops):
     """ return dict of commands in the list (generated by getwirescan_from_hdf5file)"""
     return { elem[0]: elem[4] for elem in listprops}
